package com.glxp.api.admin.controller.business;

import com.github.pagehelper.PageInfo;
import com.glxp.api.admin.entity.business.StockOrderDetailEntity;
import com.glxp.api.admin.entity.business.StockOrderEntity;
import com.glxp.api.admin.entity.business.StockOrderPrintEntity;
import com.glxp.api.admin.entity.business.StockQRCodeTextEntity;
import com.glxp.api.admin.entity.info.SystemPDFModuleEntity;
import com.glxp.api.admin.entity.info.SystemPDFTemplateEntity;
import com.glxp.api.admin.entity.inventory.StockPrintEntity;
import com.glxp.api.admin.req.business.StockQRCodeTextFilterRequest;
import com.glxp.api.admin.req.inout.DeleteRequest;
import com.glxp.api.admin.req.itextpdf.InspectionPDFTemplateRequest;
import com.glxp.api.admin.req.itextpdf.StockQRCodeTextPDFTemplateRequest;
import com.glxp.api.admin.res.PageSimpleResponse;
import com.glxp.api.admin.service.basic.BussinessTypeService;
import com.glxp.api.admin.service.basic.UdiInfoService;
import com.glxp.api.admin.service.basic.UdiRelevanceService;
import com.glxp.api.admin.service.business.StockOrderDetailService;
import com.glxp.api.admin.service.business.StockOrderDetailTempService;
import com.glxp.api.admin.service.business.StockOrderService;
import com.glxp.api.admin.service.business.StockQRCodeTextService;
import com.glxp.api.admin.service.info.SystemPDFModuleService;
import com.glxp.api.admin.service.info.SystemPDFTemplateService;
import com.glxp.api.admin.service.info.SystemParamConfigService;
import com.glxp.api.admin.service.inventory.InvStockPrintService;
import com.glxp.api.admin.thread.IoTransInoutService;
import com.glxp.api.admin.util.JasperUtils;
import com.glxp.api.common.enums.ResultEnum;
import com.glxp.api.common.res.BaseResponse;
import com.glxp.api.common.util.ResultVOUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RestController
public class StockQRCodeTextController {

    @Resource
    StockOrderService stockOrderService;
    @Resource
    StockOrderDetailService stockOrderDetailService;
    @Resource
    StockOrderDetailTempService stockOrderDetailTempService;
    @Resource
    StockQRCodeTextService stockQRCodeTextService;
    @Resource
    UdiInfoService udiInfoService;
    @Resource
    private UdiRelevanceService udiRelevanceService;
    @Resource
    private SystemPDFTemplateService systemPDFTemplateService;
    @Resource
    private SystemPDFModuleService systemPDFModuleService;
    @Resource
    private BussinessTypeService bussinessTypeService;
    @Resource
    InvStockPrintService stockPrintService;

    @Resource
    private IoTransInoutService transInoutService;
    @Autowired
    private SystemParamConfigService systemParamConfigService;

    @GetMapping("/udiwms/stock/qrcode/text/filter")
    public BaseResponse filterStockQRCodeText(StockQRCodeTextFilterRequest stockQRCodeTextFilterRequest,
                                              BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        List<StockQRCodeTextEntity> stockQRCodeTextEntityList
                = stockQRCodeTextService.filterStockQRCodeText(stockQRCodeTextFilterRequest);
        for (StockQRCodeTextEntity stockQRCodeTextEntity : stockQRCodeTextEntityList) {
            StockOrderDetailEntity stockOrderDetailEntity = stockOrderDetailService.findOne(stockQRCodeTextEntity.getDetailId());
            if (stockOrderDetailEntity != null) {
                stockQRCodeTextEntity.setCount(stockOrderDetailEntity.getCount());
                stockQRCodeTextEntity.setReCount(stockOrderDetailEntity.getReCount());
            } else {
                stockQRCodeTextEntity.setCount("0");
                stockQRCodeTextEntity.setReCount("0");
            }
        }
        PageInfo<StockQRCodeTextEntity> pageInfo;
        pageInfo = new PageInfo<>(stockQRCodeTextEntityList);
        PageSimpleResponse<StockQRCodeTextEntity> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(stockQRCodeTextEntityList);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    //-----------打印码
    @PostMapping("/udiwms/pdf/template/inspection/stock/qrcode/text/file")
    public BaseResponse inspectionStockQRCodeTextPDFFromTemplateFile(
            @RequestBody InspectionPDFTemplateRequest inspectionPDFTemplateRequest) throws Exception {

        StockPrintEntity stockPrintEntity = stockPrintService.selectById(inspectionPDFTemplateRequest.getQueryId());
        if (stockPrintEntity == null) {
            return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到该码");
        }
        SystemPDFModuleEntity systemPDFModuleEntity = systemPDFModuleService.selectById(3 + "");
        if (systemPDFModuleEntity == null) return ResultVOUtils.error(ResultEnum.DATA_NOT, "所属模块错误");
        SystemPDFTemplateEntity systemPDFTemplateEntity =
                systemPDFTemplateService.selectById(String.valueOf(systemPDFModuleEntity.getTemplateId()));
        if (systemPDFTemplateEntity == null) return ResultVOUtils.error(ResultEnum.DATA_NOT, "模板错误");


        return ResultVOUtils.success();
    }

    @PostMapping("/udiwms/pdf/template/stock/qrcode/text/file")
    public void stockQRCodeTextPDFFromTemplateFile(
            @RequestBody StockQRCodeTextPDFTemplateRequest stockQRCodeTextPDFTemplateRequest,
            HttpServletRequest request, HttpServletResponse response) throws Exception {


        SystemPDFModuleEntity systemPDFModuleEntity = systemPDFModuleService.selectById(3 + "");
        if (systemPDFModuleEntity == null) return;
        SystemPDFTemplateEntity systemPDFTemplateEntity =
                systemPDFTemplateService.selectById(String.valueOf(systemPDFModuleEntity.getTemplateId()));
        if (systemPDFTemplateEntity == null) return;

        StockPrintEntity stockPrintEntity = stockPrintService.selectById(stockQRCodeTextPDFTemplateRequest.getId());
        Map<String, Object> data = new HashMap<String, Object>();
        data.put("data", stockPrintEntity);
        JasperUtils.jasperReport(request, response, data, systemPDFTemplateEntity.getPath(), "pdf");
        stockPrintEntity.setPrintStatus("102");
        stockPrintService.updateStockPrint(stockPrintEntity);
    }

    //-----------打印订单
    @PostMapping("/udiwms/pdf/template/inspection/stock/order/file")
    public BaseResponse inspectionStockOrderPDFFromTemplateFile(
            @RequestBody InspectionPDFTemplateRequest inspectionPDFTemplateRequest) throws Exception {

        StockOrderEntity stockOrderEntity =
                stockOrderService.findById(inspectionPDFTemplateRequest.getOrderId());
        if (stockOrderEntity == null) {
            return ResultVOUtils.error(ResultEnum.DATA_NOT, "未找到该订单");
        }

        SystemPDFModuleEntity systemPDFModuleEntity = systemPDFModuleService.selectById(2 + "");
        if (systemPDFModuleEntity == null) return ResultVOUtils.error(ResultEnum.DATA_NOT, "所属模块错误");
        SystemPDFTemplateEntity systemPDFTemplateEntity =
                systemPDFTemplateService.selectById(String.valueOf(systemPDFModuleEntity.getTemplateId()));
        if (systemPDFTemplateEntity == null) return ResultVOUtils.error(ResultEnum.DATA_NOT, "模板错误");

        return ResultVOUtils.success();
    }

    @PostMapping("/udiwms/pdf/template/stock/order/file")
    public void stockOrderPDFFromTemplateFile(
            @RequestBody StockQRCodeTextPDFTemplateRequest stockQRCodeTextPDFTemplateRequest,
            HttpServletRequest request, HttpServletResponse response) throws Exception {

    	
    	/*
        StockOrderEntity stockOrderEntity =
                stockOrderService.findById(stockQRCodeTextPDFTemplateRequest.getId());
        if (stockOrderEntity == null) {
            return;
        }

        SystemPDFModuleEntity systemPDFModuleEntity = systemPDFModuleService.selectById(2 + "");
        if (systemPDFModuleEntity == null) return;
        SystemPDFTemplateEntity systemPDFTemplateEntity =
                systemPDFTemplateService.selectById(String.valueOf(systemPDFModuleEntity.getTemplateId()));
        if (systemPDFTemplateEntity == null) return;
        stockQRCodeTextPDFTemplateRequest.setPath(systemPDFTemplateEntity.getPath());
        stockQRCodeTextPDFTemplateRequest.setRowCount(systemPDFTemplateEntity.getRowCount());
        stockQRCodeTextPDFTemplateRequest.setQrcodeCount(systemPDFTemplateEntity.getQrcodeCount());
        //-----------------------------------------------
        stockQRCodeTextPDFTemplateRequest.setOrderId(stockOrderEntity.getId());

        stockQRCodeTextPDFTemplateRequest.setBillNo(stockOrderEntity.getBillNo());

        BussinessTypeEntity bussinessTypeEntity = bussinessTypeService.findBTByAction(stockOrderEntity.getBillType());
        stockQRCodeTextPDFTemplateRequest.setActionName(bussinessTypeEntity == null ? " " : bussinessTypeEntity.getName());

        StockOrderDetailFilterRequest stockOrderDetailFilterRequest = new StockOrderDetailFilterRequest();
        stockOrderDetailFilterRequest.setOrderIdFk(stockOrderEntity.getId());
        List<StockOrderDetailEntity> stockOrderDetailEntityList = stockOrderDetailService.filterStockOrderDetail(stockOrderDetailFilterRequest);

        ITextPDFUtils.exportStockOrderPDFFromTemplateFile(
                stockQRCodeTextPDFTemplateRequest, stockOrderEntity, stockOrderDetailEntityList, request, response);
	    */
        /*打印订单*/
        List<StockOrderPrintEntity> list = stockOrderService.listOrderPrint(stockQRCodeTextPDFTemplateRequest.getId());
        if (list != null && list.size() > 0) {

            SystemPDFModuleEntity systemPDFModuleEntity = systemPDFModuleService.selectById(2 + "");
            if (systemPDFModuleEntity == null) return;
            SystemPDFTemplateEntity systemPDFTemplateEntity =
                    systemPDFTemplateService.selectById(String.valueOf(systemPDFModuleEntity.getTemplateId()));
            if (systemPDFTemplateEntity == null) return;
            Map<String, Object> data = new HashMap<String, Object>();
            data.put("data", list);
            JasperUtils.jasperReport(request, response, data, systemPDFTemplateEntity.getPath(), "pdf");
//            JasperUtils.jasperReport(request, response, data, "jaspers/order_print_1.jasper", "pdf");
            StockOrderEntity updateStockOrderEntity = new StockOrderEntity();
            updateStockOrderEntity.setId(stockQRCodeTextPDFTemplateRequest.getId());
            updateStockOrderEntity.setPrintStatus("102");
            stockOrderService.updateById(updateStockOrderEntity);

        }
    }


    @GetMapping(value = "/udiwms/stock/qrcode/text/upload")
    public BaseResponse upload(StockQRCodeTextFilterRequest stockQRCodeTextFilterRequest,
                               BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        StockQRCodeTextEntity stockQRCodeTextEntity = new StockQRCodeTextEntity();
        BeanUtils.copyProperties(stockQRCodeTextFilterRequest, stockQRCodeTextEntity);
        boolean b = stockQRCodeTextService.updateById(stockQRCodeTextEntity);
        if (b) {
            return ResultVOUtils.success();
        }
        return ResultVOUtils.error(500, "修改失败");
    }

    @PostMapping("/udiwms/stock/qrcode/text/delete")
    public BaseResponse delete(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        boolean b = stockQRCodeTextService.deleteById(deleteRequest.getId());
        if (b) {
            return ResultVOUtils.success("删除成功");
        } else {
            return ResultVOUtils.error(500, "删除失败");
        }
    }
}
