package com.glxp.api.admin.controller.inventory;

import com.github.pagehelper.PageInfo;
import com.glxp.api.admin.constant.ConstantStatus;
import com.glxp.api.admin.constant.ConstantType;
import com.glxp.api.admin.entity.basic.UdiEntity;
import com.glxp.api.admin.entity.basic.UdiInfoEntity;
import com.glxp.api.admin.entity.inout.OrderEntity;
import com.glxp.api.admin.entity.inventory.InvProductDetailEntity;
import com.glxp.api.admin.entity.inventory.InvProductEntity;
import com.glxp.api.admin.req.inout.DeleteRequest;
import com.glxp.api.admin.req.inventory.FilterCodeTraceRequest;
import com.glxp.api.admin.req.inventory.FilterInvProductDetailRequest;
import com.glxp.api.admin.req.inventory.FilterInvProductRequest;
import com.glxp.api.admin.res.PageSimpleResponse;
import com.glxp.api.admin.res.basic.UdiRelevanceResponse;
import com.glxp.api.admin.res.inventory.InvProductDetailResponse;
import com.glxp.api.admin.res.inventory.InvProductPageRespnonse;
import com.glxp.api.admin.res.inventory.InvProductResponse;
import com.glxp.api.admin.res.inventory.InvProductStatResponse;
import com.glxp.api.admin.service.basic.UdiInfoService;
import com.glxp.api.admin.service.basic.UdiRelevanceService;
import com.glxp.api.admin.service.inout.OrderService;
import com.glxp.api.admin.service.inventory.InvProductDetailService;
import com.glxp.api.admin.service.inventory.InvProductService;
import com.glxp.api.admin.util.FilterUdiUtils;
import com.glxp.api.common.enums.ResultEnum;
import com.glxp.api.common.res.BaseResponse;
import com.glxp.api.common.util.ResultVOUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.glxp.api.admin.constant.Constant;

import static com.glxp.api.admin.constant.Constant.SYSTEM_CUSTOMER_ID;


@RestController
public class InvProductsController {

    @Resource
    InvProductService invProductService;
    @Resource
    InvProductDetailService invProductDetailService;
    @Resource
    OrderService orderService;
    @Resource
    private UdiRelevanceService udiRelevanceService;
    @Resource
    private UdiInfoService udiInfoService;

    @GetMapping("spms/inv/products/filter")
    public BaseResponse filterInvProduct(FilterInvProductRequest filterInvProductRequest) {
        boolean showSup = false;
        List<InvProductResponse> invProductResponses = invProductService.filterJoinInvProduct(filterInvProductRequest);
        PageInfo<InvProductResponse> pageInfo;
        pageInfo = new PageInfo<>(invProductResponses);
        InvProductPageRespnonse<InvProductResponse> pageSimpleResponse = new InvProductPageRespnonse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(invProductResponses);
        pageSimpleResponse.setShowSup(showSup);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @GetMapping("spms/inv/products/filterDetail")
    public BaseResponse filterInvProductDetail(FilterInvProductDetailRequest filterInvProductRequest) {
        if (SYSTEM_CUSTOMER_ID.equals(filterInvProductRequest.getCustomerId())) {
            filterInvProductRequest.setCustomerId(null);
        }
        List<InvProductDetailEntity> invProductDetailEntities = invProductDetailService.filterInvProduct(filterInvProductRequest);
        PageInfo<InvProductDetailEntity> pageInfo;
        pageInfo = new PageInfo<>(invProductDetailEntities);

        List<InvProductDetailResponse> invProductDetailResponses = new ArrayList<>();

        if (invProductDetailEntities.size() > 0) {
            for (InvProductDetailEntity invProductDetailEntity : invProductDetailEntities) {
                InvProductDetailResponse invProductDetailResponse = new InvProductDetailResponse();
                BeanUtils.copyProperties(invProductDetailEntity, invProductDetailResponse);
                if (invProductDetailEntity.getMainAction().equals(ConstantType.TYPE_OUT)) {
                    invProductDetailResponse.setMainActionStr("出库");
                    invProductDetailResponse.setOutCount(invProductDetailEntity.getCount());
                } else {
                    invProductDetailResponse.setMainActionStr("入库");
                    invProductDetailResponse.setInCount(invProductDetailEntity.getCount());
                }
                invProductDetailResponses.add(invProductDetailResponse);
            }
        }


        PageSimpleResponse<InvProductDetailResponse> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(invProductDetailResponses);
        return ResultVOUtils.success(pageSimpleResponse);
    }


    @PostMapping("spms/inv/products/delete")
    public BaseResponse deleteInvProduct(@RequestBody DeleteRequest deleteRequest, BindingResult bindingResult) {

        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, bindingResult.getFieldError().getDefaultMessage());
        }
        String id = deleteRequest.getId();
        InvProductEntity invProductEntity = invProductService.selectById(id);
        if (invProductEntity != null) {
            invProductService.deleteById(id);
            FilterInvProductDetailRequest detailRequest = new FilterInvProductDetailRequest();
            detailRequest.setSupId(invProductEntity.getSupId());
            detailRequest.setBatchNo(invProductEntity.getBatchNo());
            detailRequest.setProductIdFk(invProductEntity.getRelIdFk());
            invProductDetailService.deleteByProductId(detailRequest);
            return ResultVOUtils.success("删除成功");
        } else {
            return ResultVOUtils.error(500, "删除失败！");
        }
    }


    @GetMapping("spms/inv/products/stat")
    public BaseResponse statInvProduct(FilterInvProductDetailRequest filterInvProductDetailRequest) {

        if (filterInvProductDetailRequest.getCustomerId() != null && filterInvProductDetailRequest.getCustomerId().equals(SYSTEM_CUSTOMER_ID)) {
            filterInvProductDetailRequest.setCustomerId(null);
        }

        InvProductStatResponse invProductStatResponse = new InvProductStatResponse();
        //统计预入库数量
        FilterInvProductDetailRequest temp1 = new FilterInvProductDetailRequest();
        BeanUtils.copyProperties(filterInvProductDetailRequest, temp1);
        temp1.setPurchaseType(ConstantStatus.PRUCHASE_ADVANCE);
        invProductStatResponse.setAdvanceCount(invProductDetailService.statCount(temp1));
        //统计普通采购数量
        FilterInvProductDetailRequest temp2 = new FilterInvProductDetailRequest();
        BeanUtils.copyProperties(filterInvProductDetailRequest, temp2);
        temp2.setPurchaseType(ConstantStatus.PRUCHASE_COMMON);
        invProductStatResponse.setCommonCount(invProductDetailService.statCount(temp2));
        //统计入库数量
        FilterInvProductDetailRequest temp3 = new FilterInvProductDetailRequest();
        BeanUtils.copyProperties(filterInvProductDetailRequest, temp3);
        temp3.setMainAction(ConstantType.TYPE_PUT);
        invProductStatResponse.setInCount(invProductDetailService.statCount(temp3));
        //统计出库数量
        FilterInvProductDetailRequest temp4 = new FilterInvProductDetailRequest();
        BeanUtils.copyProperties(filterInvProductDetailRequest, temp4);
        temp4.setMainAction(ConstantType.TYPE_OUT);
        invProductStatResponse.setOutCount(invProductDetailService.statCount(temp4));
        return ResultVOUtils.success(invProductStatResponse);
    }

    @GetMapping("spms/inv/products/trace")
    public BaseResponse filterTrace(FilterCodeTraceRequest filterCodeTraceRequest) {
        if (filterCodeTraceRequest.getCode() == null) {
            return ResultVOUtils.success();
        }
        FilterInvProductDetailRequest filterInvProductDetailRequest = new FilterInvProductDetailRequest();
        filterInvProductDetailRequest.setCode(filterCodeTraceRequest.getCode());
        filterInvProductDetailRequest.setSupId(filterCodeTraceRequest.getSupId());
        List<InvProductDetailEntity> invProductDetailEntities = invProductDetailService.filterInvProduct(filterInvProductDetailRequest);
        if (invProductDetailEntities.size() > 0) {
            InvProductDetailEntity invProductDetailEntity = new InvProductDetailEntity();
            FilterInvProductDetailRequest filterRequest = new FilterInvProductDetailRequest();
            filterRequest.setBatchNo(invProductDetailEntity.getBatchNo());
            filterRequest.setProductIdFk(invProductDetailEntity.getProductIdFk());
            filterRequest.setSupId(filterCodeTraceRequest.getSupId());
            List<InvProductDetailEntity> resultLists = invProductDetailService.filterInvProduct(filterInvProductDetailRequest);

            List<InvProductDetailResponse> invProductDetailResponses = new ArrayList<>();

            if (invProductDetailEntities.size() > 0) {
                for (InvProductDetailEntity temp : resultLists) {
                    InvProductDetailResponse invProductDetailResponse = new InvProductDetailResponse();
                    BeanUtils.copyProperties(temp, invProductDetailResponse);
                    if (temp.getMainAction().equals(ConstantType.TYPE_OUT)) {
                        invProductDetailResponse.setMainActionStr("出库");
                        invProductDetailResponse.setOutCount(temp.getCount());
                    } else {
                        invProductDetailResponse.setMainActionStr("入库");
                        invProductDetailResponse.setInCount(temp.getCount());
                    }
                    invProductDetailResponses.add(invProductDetailResponse);
                }
            }


            PageInfo<InvProductDetailResponse> pageInfo;
            pageInfo = new PageInfo<>(invProductDetailResponses);
            InvProductPageRespnonse<InvProductDetailResponse> pageSimpleResponse = new InvProductPageRespnonse<>();
            pageSimpleResponse.setTotal(pageInfo.getTotal());
            pageSimpleResponse.setList(invProductDetailResponses);
            return ResultVOUtils.success(pageSimpleResponse);
        } else {
            return ResultVOUtils.error(500, "未查询到数据！");
        }


    }

    @GetMapping("spms/inv/products/order/trace")
    public BaseResponse filterOrderTrace(FilterCodeTraceRequest filterCodeTraceRequest) {
        if (filterCodeTraceRequest.getCode() == null) {
            return ResultVOUtils.success();
        }
        UdiEntity udiEntity = FilterUdiUtils.getUdi(filterCodeTraceRequest.getCode());
        UdiRelevanceResponse udiInfoBean = udiRelevanceService.selectByNameCode(udiEntity.getUdi());
        List<UdiInfoEntity> udiInfoEntities = udiInfoService.findByUuids(udiInfoBean.getUuid());
        String code = null;
        if (udiInfoEntities != null && udiInfoEntities.size() > 1) {
            code = FilterUdiUtils.transGlxpNoSerStr(udiEntity);
        } else {
            code = filterCodeTraceRequest.getCode();
        }


        FilterInvProductDetailRequest filterInvProductDetailRequest = new FilterInvProductDetailRequest();
        filterInvProductDetailRequest.setCode(code);
        filterInvProductDetailRequest.setSupId(filterCodeTraceRequest.getSupId());
        List<InvProductDetailEntity> invProductDetailEntities = invProductDetailService.filterInvProduct(filterInvProductDetailRequest);
        if (invProductDetailEntities.size() > 0) {
            Map<String, String> filterMap = new HashMap<>();

            for (InvProductDetailEntity invProductDetailEntity : invProductDetailEntities) {
                filterMap.put(invProductDetailEntity.getOrderIdFk(), invProductDetailEntity.getOrderIdFk());
            }
            List<String> orderIds = new ArrayList<>();
            for (String key : filterMap.keySet()) {
                orderIds.add(key);
            }
            List<OrderEntity> orderEntities = orderService.filterListByOrder(orderIds);
            PageInfo<OrderEntity> pageInfo;
            pageInfo = new PageInfo<>(orderEntities);
            InvProductPageRespnonse<OrderEntity> pageSimpleResponse = new InvProductPageRespnonse<>();
            pageSimpleResponse.setTotal(pageInfo.getTotal());
            pageSimpleResponse.setList(orderEntities);
            return ResultVOUtils.success(pageSimpleResponse);
        } else {
            return ResultVOUtils.error(500, "未查询到数据！");
        }

    }


}
