package com.glxp.api.admin.thread;

import com.glxp.api.admin.constant.RedisContant;
import com.glxp.api.admin.dao.schedule.ScheduledDao;
import com.glxp.api.admin.entity.info.ScheduledEntity;
import com.glxp.api.admin.entity.info.SystemParamConfigEntity;
import com.glxp.api.admin.req.info.ScheduledRequest;
import com.glxp.api.admin.service.info.SystemParamConfigService;
import com.glxp.api.admin.util.RedisUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.SchedulingConfigurer;
import org.springframework.scheduling.config.ScheduledTaskRegistrar;
import org.springframework.scheduling.support.CronTrigger;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;


@Component
@EnableScheduling
public class HeartTask implements SchedulingConfigurer {

    final Logger logger = LoggerFactory.getLogger(HeartTask.class);
    @Resource
    protected ScheduledDao scheduledDao;
    @Resource
    RedisUtil redisUtil;
    @Resource
    SystemParamConfigService systemParamConfigService;
    @Resource
    DlSpOrderService dlSpOrderService;

    @Override
    public void configureTasks(ScheduledTaskRegistrar scheduledTaskRegistrar) {

        scheduledTaskRegistrar.addTriggerTask(() -> process(),
                triggerContext -> {
                    ScheduledRequest scheduledRequest = new ScheduledRequest();
                    scheduledRequest.setCronName("heartTask");
                    ScheduledEntity scheduledEntity = scheduledDao.findScheduled(scheduledRequest);
                    String cron = scheduledEntity.getCron();
                    if (cron.isEmpty()) {
                        logger.error("cron is null");
                    }
                    return new CronTrigger(cron).nextExecutionTime(triggerContext);
                });
    }


    private void process() {


        SystemParamConfigEntity systemParamConfigEntity = systemParamConfigService.selectByParamKey("dl_order_status");
        long timeInterval = Long.parseLong(systemParamConfigEntity.getParamValue()) * 60 * 1000;
        long curTime = System.currentTimeMillis();
        //任务一,定时下载供应商平台已完成单据
        Long lastTime = (Long) redisUtil.get(RedisContant.DL_ORDER_STATUS);
        if (lastTime == null) {
            redisUtil.set(RedisContant.DL_ORDER_STATUS, System.currentTimeMillis());
        }
        if (curTime - lastTime > timeInterval) {
            logger.info("每分钟执行一次单据下载");
            redisUtil.set(RedisContant.DL_ORDER_STATUS, curTime);
            dlSpOrderService.dlOrdedrs();
        }

    }
}
