package com.glxp.api.admin.thread;

import com.glxp.api.admin.constant.Constant;
import com.glxp.api.admin.constant.ConstantStatus;
import com.glxp.api.admin.constant.ConstantType;
import com.glxp.api.admin.entity.basic.*;
import com.glxp.api.admin.entity.info.CompanyEntity;
import com.glxp.api.admin.entity.info.SystemParamConfigEntity;
import com.glxp.api.admin.entity.inout.ErpOrderEntity;
import com.glxp.api.admin.entity.inout.FilterErpOrderRequest;
import com.glxp.api.admin.entity.inout.OrderEntity;
import com.glxp.api.admin.entity.inout.WarehouseEntity;
import com.glxp.api.admin.entity.inventory.InvProductDetailEntity;
import com.glxp.api.admin.entity.inventory.InvProductEntity;
import com.glxp.api.admin.req.basic.FilterUdiInfoRequest;
import com.glxp.api.admin.req.inventory.FilterInvProductDetailRequest;
import com.glxp.api.admin.res.basic.UdiRelevanceResponse;
import com.glxp.api.admin.res.inventory.InvProductDetailJoinResponse;
import com.glxp.api.admin.service.basic.*;
import com.glxp.api.admin.service.info.CompanyService;
import com.glxp.api.admin.service.info.SystemParamConfigService;
import com.glxp.api.admin.service.inout.CodesService;
import com.glxp.api.admin.service.inout.CodesTempService;
import com.glxp.api.admin.service.inout.OrderDetailService;
import com.glxp.api.admin.service.inout.OrderService;
import com.glxp.api.admin.service.inventory.InvProductDetailService;
import com.glxp.api.admin.service.inventory.InvProductService;
import com.glxp.api.admin.util.CustomUtil;
import com.glxp.api.admin.util.DateUtil;
import com.glxp.api.admin.util.FilterUdiUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

@Service
public class InvProductsTrService {

    @Resource
    private OrderService orderService;
    @Resource
    private OrderDetailService myErpOrderService;
    @Resource
    private CodesService codesService;
    @Resource
    private CodesTempService codesTempService;
    @Resource
    private UdiRelevanceService udiRelevanceService;
    @Resource
    private UdiInfoService udiInfoService;
    @Resource
    private BussinessTypeService bussinessTypeService;
    @Resource
    private BussinessLocalTypeService bussinessLocalTypeService;
    @Resource
    private InvProductService invProductService;
    @Resource
    private InvProductDetailService invProductDetailService;
    @Resource
    private BussinessChangeTypeService bussinessChangeTypeService;
    @Resource
    private BasicUnitMaintainService basicUnitMaintainService;

    @Resource
    @Lazy
    private IoTransInoutService ioTransInoutService;
    @Resource
    CompanyService companyService;
    @Resource
    SystemParamConfigService systemParamConfigService;

    @Async
    public void genInvProducts(String orderId) {
        OrderEntity orderEntity = orderService.findById(orderId);
        if (orderEntity.getStatus() == ConstantStatus.ORDER_STATUS_SUCCESS &&
                (orderEntity.getContrastStatus() == ConstantStatus.ORDER_CHECK_SUCCESS ||
                        orderEntity.getContrastStatus() == ConstantStatus.ORDER_CHECK_UN)) {

            BussinessTypeEntity bussinessTypeEntity = bussinessTypeService.findBTByAction(orderEntity.getAction());
            if (bussinessTypeEntity.isInnerOrder()) {//内部单据，不计入库存
                return;
            }
            BussinessLocalTypeEntity bussinessLocalTypeEntity = bussinessLocalTypeService.findBTByAction(bussinessTypeEntity.getLocalAction());

            FilterErpOrderRequest filterErpOrderRequest = new FilterErpOrderRequest();
            filterErpOrderRequest.setOrderId(orderId);
            List<ErpOrderEntity> erpOrderEntities = myErpOrderService.filterAllMyErpOrder(filterErpOrderRequest);

            //根据条码生成库存产品列表（产品ID,批次号，供应商）唯一键插入
            List<WarehouseEntity> warehouseEntityList = codesService.findByReceiptId(orderId);
            for (WarehouseEntity warehouseEntity : warehouseEntityList) {
                ErpOrderEntity erpOrderEntity = getErpOrders(warehouseEntity, erpOrderEntities);
                //普通出入库
                InvProductEntity invProductEntity = invProductService.selectByUuid(erpOrderEntity.getGoodsid(), erpOrderEntity.getBatchNo(), warehouseEntity.getSupId());
                if (invProductEntity == null) {
                    invProductEntity = buildInvProduct(erpOrderEntity.getGoodsid(), erpOrderEntity, orderEntity, warehouseEntity);
                    invProductEntity.setUnitFk(orderEntity.getFromCorpId());
                    invProductService.insertInvProduct(invProductEntity);
                } else {
                    int actCount = getActCount(warehouseEntity);
                    int count = actCount * warehouseEntity.getCount();
                    if (orderEntity.getMainAction().equals(ConstantType.TYPE_OUT)) {
                        invProductEntity.setOutCount(invProductEntity.getOutCount() + count);
                    } else if (orderEntity.getMainAction().equals(ConstantType.TYPE_PUT)) {
                        invProductEntity.setInCount(invProductEntity.getInCount() + count);
                    }
                    invProductService.updateInvProduct(invProductEntity);
                }

            }

            //根据单据详情与条码生成库存码明细
            List<InvProductDetailEntity> mInvProductDetailEntities = new ArrayList<>();
            if (erpOrderEntities != null && erpOrderEntities.size() > 0) {
                for (ErpOrderEntity erpOrderEntity : erpOrderEntities) {
                    String erpId = erpOrderEntity.getGoodsid();
                    FilterUdiInfoRequest filterUdiInfoRequest = new FilterUdiInfoRequest();
                    filterUdiInfoRequest.setId(erpId);
                    List<UdiRelevanceResponse> udiRelevanceResponses = udiRelevanceService.filterUdiRelevance(filterUdiInfoRequest);
                    String relId = null;
                    if (udiRelevanceResponses != null && udiRelevanceResponses.size() > 0) {
                        relId = udiRelevanceResponses.get(0).getId() + "";
                    }
                    if (relId != null) {
                        List<InvProductDetailEntity> invProductDetailEntities;
                        invProductDetailEntities = buildInvProductDetail(orderId, erpOrderEntity, orderEntity, 2, false);
                        if (invProductDetailEntities != null && invProductDetailEntities.size() > 0) {
                            mInvProductDetailEntities.addAll(invProductDetailEntities);
                        }
                    }
                }
            }

            //单据流转
            BussinessChangeTypeEntity bussinessChangeTypeEntity = bussinessChangeTypeService.findFirstByAction(bussinessLocalTypeEntity.getLocalAction());
            if (bussinessLocalTypeEntity.getChangeEnable() && bussinessChangeTypeEntity != null) {
                //普通出库
                if (ConstantType.TYPE_OUT.equals(bussinessTypeEntity.getMainAction())) {
                    List<WarehouseEntity> datas = addOutOrder(orderEntity, mInvProductDetailEntities);//1.先计算现有库存，
//                    insetInv(bussinessTypeEntity.isAdvanceType(), mInvProductDetailEntities);//2.插入当前库存
                    List<WarehouseEntity> temps = filterMapCodes(datas);
                    buildInOrder(bussinessChangeTypeEntity, temps, orderEntity);   //3.生成流转单据
                }

            } else {
                insetInv(mInvProductDetailEntities);//2.插入当前库存
            }
        }

    }

    //普通出库补单
    public List<WarehouseEntity> addOutOrder(OrderEntity orderEntity, List<InvProductDetailEntity> invProductDetailEntities) {
        List<WarehouseEntity> warehouseEntities = codesService.findByReceiptId(orderEntity.getId());
        List<WarehouseEntity> inList = new ArrayList<>();
        for (WarehouseEntity warehouseEntity : warehouseEntities) {
            //获取普通出入库结余数量
            int actCount = getActCount(warehouseEntity);
            UdiInfoEntity udiInfoEntity = getMinDi(warehouseEntity);
            String code = warehouseEntity.getCode();
            if (udiInfoEntity.getDiType() == ConstantStatus.DITYPE_PACK || udiInfoEntity.getDiType() == ConstantStatus.DITYPE_SYDY
                    || (udiInfoEntity.getSjcpbm() != null && !"".equals(udiInfoEntity.getSjcpbm()))) {
                warehouseEntity.setNameCode(udiInfoEntity.getNameCode());
                code = FilterUdiUtils.transGlxpNoSerStr(warehouseEntity);
//                warehouseEntity.setCode(code);
//                warehouseEntity.setCount(actCount * warehouseEntity.getCount());
            }
            int invCount = getCountByOrder(null, warehouseEntity.getCode(), warehouseEntity.getSupId());
            if (invCount <= 0) {
                invCount = getCountByOrder(null, code, warehouseEntity.getSupId());
            }
            if (invCount > 0) {
                int count = actCount * warehouseEntity.getCount();
                if (count > invCount) {
                    int lea = count - invCount;
                    warehouseEntity.setCount(lea / (getActCount(warehouseEntity)));
                    inList.add(warehouseEntity);
                }
            } else {
                inList.add(warehouseEntity);
            }
            InvProductDetailEntity invProductDetailEntity = filterInvByCode(invProductDetailEntities, warehouseEntity.getCode());
            insetInvSingle(invProductDetailEntity);
            warehouseEntity.setCode(code);
        }
        return inList;
    }


    public ErpOrderEntity getErpOrders(WarehouseEntity warehouseEntity, List<ErpOrderEntity> erpOrderEntities) {

        for (ErpOrderEntity erpOrderEntity : erpOrderEntities) {
            if (warehouseEntity.getRelId().equals(erpOrderEntity.getGoodsid())) {
                if ((warehouseEntity.getBatchNo() == null && erpOrderEntity.getBatchNo() == null) ||
                        warehouseEntity.getBatchNo().equals(erpOrderEntity.getBatchNo())) {
                    return erpOrderEntity;
                }
            }
        }
        return null;
    }


    //生成普通入库单据
    public void buildInOrder(BussinessChangeTypeEntity
                                     bussinessChangeTypeEntity, List<WarehouseEntity> useInList, OrderEntity orderEntity) {
        if (useInList.size() <= 0) {
            return;
        }
        //采购入库生成单据
        Map<String, List<WarehouseEntity>> filterSupMaps = new HashMap<>();
        List<WarehouseEntity> unkonwCorpList = new ArrayList<>();

        //根据库存，过滤供应商，条码分组
        for (WarehouseEntity warehouseEntity : useInList) {
            if (warehouseEntity.getSupId() != null) {
                if (filterSupMaps.get(warehouseEntity.getSupId()) == null) {
                    List<WarehouseEntity> temps = new ArrayList<>();
                    temps.add(warehouseEntity);
                    filterSupMaps.put(warehouseEntity.getSupId(), temps);
                } else {
                    filterSupMaps.get(warehouseEntity.getSupId()).add(warehouseEntity);
                }
            } else
                unkonwCorpList.add(warehouseEntity);
        }

        //有供应商生成采购入库单据
        for (String corpName : filterSupMaps.keySet()) {
            List<WarehouseEntity> temps;
            temps = filterSupMaps.get(corpName);
            OrderEntity outOrder = new OrderEntity();
            BeanUtils.copyProperties(orderEntity, outOrder);
            outOrder.setActDate(DateUtil.getBeforeDay(outOrder.getActDate(), bussinessChangeTypeEntity.getBeforeTime()));
            outOrder.setAction(bussinessChangeTypeEntity.getScAction());
            outOrder.setMainAction(ConstantType.TYPE_PUT);
            outOrder.setContrastStatus(ConstantStatus.ORDER_CHECK_UN);
            outOrder.setErpFk(null);
            outOrder.setFromType(ConstantStatus.FROM_CHANGE);
            outOrder.setId(CustomUtil.getId());
            BasicUnitMaintainEntity basicUnitMaintainEntity = basicUnitMaintainService.selectByErpId(corpName);
            outOrder.setFromCorp(basicUnitMaintainEntity.getName());
            outOrder.setFromCorpId(corpName);
            SystemParamConfigEntity systemParamConfigEntity = systemParamConfigService.selectByParamKey("additional_auto_submit");
            if ("1".equals(systemParamConfigEntity.getParamValue())) {
                outOrder.setStatus(ConstantStatus.ORDER_STATUS_PROCESS);
            } else {
                outOrder.setStatus(ConstantStatus.ORDER_STATUS_ADDITIONAL);
            }

            orderService.insertOrder(outOrder);
            for (WarehouseEntity warehouseEntity : temps) {
                warehouseEntity.setOrderId(outOrder.getId());
                warehouseEntity.setId(null);
                warehouseEntity.setAction(bussinessChangeTypeEntity.getScAction());
                warehouseEntity.setMainAction(ConstantType.TYPE_PUT);
            }
            codesTempService.insertCodesTemp(temps);
//            ioTransInoutService.transInout(outOrder.getId());
        }


        //无供应商，一个条码生成一个错误单据，到时候利用单据合并生成同一个单据
        for (WarehouseEntity warehouseEntity : unkonwCorpList) {
            OrderEntity outOrder = new OrderEntity();
            BeanUtils.copyProperties(orderEntity, outOrder);
            outOrder.setActDate(DateUtil.getBeforeDay(outOrder.getActDate(), bussinessChangeTypeEntity.getBeforeTime()));
            outOrder.setAction(bussinessChangeTypeEntity.getScAction());
            outOrder.setMainAction(ConstantType.TYPE_PUT);
            SystemParamConfigEntity systemParamConfigEntity = systemParamConfigService.selectByParamKey("additional_auto_submit");
            if ("1".equals(systemParamConfigEntity.getParamValue())) {
                outOrder.setStatus(ConstantStatus.ORDER_STATUS_PROCESS);
            } else {
                outOrder.setStatus(ConstantStatus.ORDER_STATUS_ADDITIONAL);
            }

            outOrder.setContrastStatus(ConstantStatus.ORDER_CHECK_UN);
            outOrder.setRemark("未选择供应商");
            outOrder.setErpFk(null);
            outOrder.setId(CustomUtil.getId());
            outOrder.setFromCorp(null);
            outOrder.setFromCorpId(null);
            orderService.insertOrder(outOrder);
            warehouseEntity.setOrderId(outOrder.getId());
            warehouseEntity.setId(null);
            warehouseEntity.setAction(bussinessChangeTypeEntity.getScAction());
            warehouseEntity.setMainAction(ConstantType.TYPE_PUT);
            warehouseEntity.setFromCorp(null);
            warehouseEntity.setFromCorpId(null);
            codesTempService.insertCodesTempSingle(warehouseEntity);
        }


    }


    //生成库存
    private InvProductEntity buildInvProduct(String relId, ErpOrderEntity erpOrderEntity, OrderEntity orderEntity, WarehouseEntity warehouseEntity) {
        InvProductEntity invProductEntity = new InvProductEntity();
        invProductEntity.setRelIdFk(relId);
        invProductEntity.setBatchNo(erpOrderEntity.getBatchNo());
        invProductEntity.setExpireDate(erpOrderEntity.getExpireDate());
        invProductEntity.setProductionDate(erpOrderEntity.getProductDate());
        invProductEntity.setGgxh(erpOrderEntity.getPackSpec());
        invProductEntity.setSupId(warehouseEntity.getSupId());
        invProductEntity.setNameCode(erpOrderEntity.getNameCode());
        invProductEntity.setProductsName(erpOrderEntity.getCoName());
        invProductEntity.setYlqxzcrbarmc(erpOrderEntity.getProductCompany());
        invProductEntity.setZczbhhzbapzbh(erpOrderEntity.getAuthCode());
        int count = getActCount(warehouseEntity) * warehouseEntity.getCount();
        if (orderEntity.getMainAction().equals(ConstantType.TYPE_OUT)) {
            invProductEntity.setOutCount(count);
        } else if (orderEntity.getMainAction().equals(ConstantType.TYPE_PUT)) {
            invProductEntity.setInCount(count);
        }

        return invProductEntity;
    }

    //生成库存条码
    private List<InvProductDetailEntity> buildInvProductDetail(String orderId, ErpOrderEntity erpOrderEntity,
                                                               OrderEntity orderEntity, Integer purchaseType, boolean isPre) {

        List<InvProductDetailEntity> mInvProductDetailEntities = new ArrayList<>();
        List<WarehouseEntity> warehouseEntities = codesService.findByReceiptId(orderId);
        if (warehouseEntities != null && warehouseEntities.size() > 0) {
            for (WarehouseEntity warehouseEntity : warehouseEntities) {
                if (warehouseEntity.getRelId().equals(erpOrderEntity.getGoodsid())) {
                    if ((warehouseEntity.getBatchNo() == null && erpOrderEntity.getBatchNo() == null) ||
                            warehouseEntity.getBatchNo().equals(erpOrderEntity.getBatchNo())) {
                        InvProductDetailEntity invProductDetailEntity = new InvProductDetailEntity();
                        invProductDetailEntity.setOriginCode(warehouseEntity.getCode());
                        invProductDetailEntity.setProductIdFk(erpOrderEntity.getGoodsid() + "");
                        int actCount = getActCount(warehouseEntity);

                        String code = warehouseEntity.getCode();
                        UdiInfoEntity udiInfoEntity = getMinDi(warehouseEntity);
                        if (udiInfoEntity.getDiType() == ConstantStatus.DITYPE_PACK || udiInfoEntity.getDiType() == ConstantStatus.DITYPE_SYDY
                                || (udiInfoEntity.getSjcpbm() != null && !"".equals(udiInfoEntity.getSjcpbm()))) {
                            warehouseEntity.setNameCode(udiInfoEntity.getNameCode());
                            code = FilterUdiUtils.transGlxpNoSerStr(warehouseEntity);
                            warehouseEntity.setCode(code);
                        }
                        invProductDetailEntity.setCode(code);
                        invProductDetailEntity.setBatchNo(warehouseEntity.getBatchNo());
                        invProductDetailEntity.setProductionDate(warehouseEntity.getProduceDate());
                        invProductDetailEntity.setExpireDate(warehouseEntity.getExpireDate());
                        invProductDetailEntity.setAction(warehouseEntity.getAction());
                        invProductDetailEntity.setMainAction(orderEntity.getMainAction());
                        invProductDetailEntity.setOrderIdFk(warehouseEntity.getOrderId());
                        invProductDetailEntity.setCount(actCount * warehouseEntity.getCount());
                        if (purchaseType != null) {
                            invProductDetailEntity.setPurchaseType(purchaseType);
                        }
                        invProductDetailEntity.setStockIdFk(orderEntity.getErpFk());
                        invProductDetailEntity.setUnitFk(orderEntity.getFromCorpId());
                        invProductDetailEntity.setUpdateTime(new Date());
                        if (orderEntity.getMainAction().equals(ConstantType.TYPE_OUT)) {
                            if (warehouseEntity.getSupId() != null) {
                                invProductDetailEntity.setSupId(warehouseEntity.getSupId());
                            } else {
                                FilterInvProductDetailRequest filterInvProductDetailRequest = new FilterInvProductDetailRequest();
                                filterInvProductDetailRequest.setMainAction(ConstantType.TYPE_PUT);
                                filterInvProductDetailRequest.setCode(warehouseEntity.getCode());
                                List<InvProductDetailEntity> temps = null;
                                temps = invProductDetailService.filterInvProduct(filterInvProductDetailRequest);
                                if (temps.size() > 0) {
                                    invProductDetailEntity.setSupId(temps.get(0).getSupId());
                                }
                            }
                        } else {
                            invProductDetailEntity.setSupId(orderEntity.getFromCorpId());
                        }

                        mInvProductDetailEntities.add(invProductDetailEntity);
                    }
                }
            }
        }
        return mInvProductDetailEntities;
    }

    public void insetInv(List<InvProductDetailEntity> invProductDetailEntities) {
        invProductDetailService.insertInvProducts(invProductDetailEntities);
    }

    public void insetInvSingle(InvProductDetailEntity invProductDetailEntity) {
        List<InvProductDetailEntity> invProductDetailEntities = new ArrayList<>();
        invProductDetailEntities.add(invProductDetailEntity);
        invProductDetailService.insertInvProducts(invProductDetailEntities);
    }


    public InvProductDetailEntity filterInvByCode(List<InvProductDetailEntity> invProductDetailEntities, String code) {

        for (InvProductDetailEntity invProductDetailEntity : invProductDetailEntities) {
            if (invProductDetailEntity.getOriginCode().equals(code)) {
                return invProductDetailEntity;
            }
        }
        return null;

    }

    public int getActCount(WarehouseEntity warehouseEntity) {
        UdiRelevanceResponse udiInfoBean = udiRelevanceService.selectByNameCode(warehouseEntity.getNameCode());
        if (udiInfoBean != null) {
            if (udiInfoBean.getIsUseDy() == 1 && udiInfoBean.getDiType() != 2) {
                if (udiInfoBean.getBhzxxsbzsl() == 0)
                    return udiInfoBean.getZxxsbzbhsydysl();
                else
                    return udiInfoBean.getZxxsbzbhsydysl() * udiInfoBean.getBhzxxsbzsl();
            } else {
                return udiInfoBean.getBhzxxsbzsl();
            }
        }
        return 1;
    }

    public boolean isMutiPack(WarehouseEntity warehouseEntity) {
        UdiRelevanceResponse udiInfoBean = udiRelevanceService.selectByNameCode(warehouseEntity.getNameCode());
        List<UdiInfoEntity> udiInfoEntities = udiInfoService.findByUuids(udiInfoBean.getUuid());
        if (udiInfoBean != null && udiInfoEntities.size() > 1) {
            return true;
        }
        return false;
    }

    public UdiInfoEntity getMinDi(WarehouseEntity warehouseEntity) {
        UdiRelevanceResponse udiInfoBean = udiRelevanceService.selectByNameCode(warehouseEntity.getNameCode());
        List<UdiInfoEntity> udiInfoEntities = udiInfoService.findByUuids(udiInfoBean.getUuid());
        if (udiInfoBean != null) {
            for (UdiInfoEntity udiInfoEntity : udiInfoEntities) {
                if (udiInfoBean.getIsUseDy() == 1) {
                    if (udiInfoEntity.getDiType() == ConstantStatus.DITYPE_SYDY) {
                        return udiInfoEntity;
                    }
                } else {
                    if (udiInfoEntity.getDiType() == ConstantStatus.DITYPE_MAIN) {
                        return udiInfoEntity;
                    }
                }
            }
        }
        return null;
    }


    //根据条码获取库存结余数量
    public int getCountByOrder(String mainAction, String code, String supId) {
        FilterInvProductDetailRequest filterInvProductDetailRequest = new FilterInvProductDetailRequest();
        filterInvProductDetailRequest.setCode(code);
        filterInvProductDetailRequest.setSupId(supId);
        if (mainAction != null)
            filterInvProductDetailRequest.setMainAction(mainAction);
        List<InvProductDetailJoinResponse> detailJoinResponseList
                = invProductDetailService.filterJoinInvProduct(filterInvProductDetailRequest);
        int invCount = 0;
        if (detailJoinResponseList != null && detailJoinResponseList.size() > 0) {
            for (InvProductDetailJoinResponse invProductDetailJoinResponse : detailJoinResponseList) {
                if (invProductDetailJoinResponse.getMainAction().equals(ConstantType.TYPE_OUT)) {
                    invCount = invCount - invProductDetailJoinResponse.getCount();
                } else {
                    invCount = invCount + invProductDetailJoinResponse.getCount();
                }

            }
        }
        return invCount;
    }


    //根据条码获取库存结余数量
    public int getCountByProduct(String mainAction, String productId, String batchNo, String supId) {
        FilterInvProductDetailRequest filterInvProductDetailRequest = new FilterInvProductDetailRequest();
        filterInvProductDetailRequest.setProductIdFk(productId);
        filterInvProductDetailRequest.setBatchNo(batchNo);
        filterInvProductDetailRequest.setSupId(supId);
        if (mainAction != null)
            filterInvProductDetailRequest.setMainAction(mainAction);
        List<InvProductDetailJoinResponse> detailJoinResponseList
                = invProductDetailService.filterJoinInvProduct(filterInvProductDetailRequest);
        int invCount = 0;
        if (detailJoinResponseList != null && detailJoinResponseList.size() > 0) {
            for (InvProductDetailJoinResponse invProductDetailJoinResponse : detailJoinResponseList) {
                if (invProductDetailJoinResponse.getMainAction().equals(ConstantType.TYPE_OUT)) {
                    invCount = invCount - invProductDetailJoinResponse.getCount();
                } else {
                    invCount = invCount + invProductDetailJoinResponse.getCount();
                }
            }
        }
        return invCount;
    }

    //合并条码
    public List<WarehouseEntity> filterMapCodes(List<WarehouseEntity> warehouseEntityList) {
        Map<String, WarehouseEntity> filterMap = new HashMap<>();
        for (WarehouseEntity warehouseEntity : warehouseEntityList) {
            WarehouseEntity temp = filterMap.get(warehouseEntity.getCode());
            if (temp == null) {
                filterMap.put(warehouseEntity.getCode(), warehouseEntity);
            } else {
                WarehouseEntity tempEntity = filterMap.get(warehouseEntity.getCode());
                filterMap.get(warehouseEntity.getCode()).setCount(tempEntity.getCount() + 1);
            }
        }
        List<WarehouseEntity> results = new ArrayList<>();
        for (WarehouseEntity warehouseEntity : filterMap.values()) {
            results.add(warehouseEntity);
        }
        return results;
    }
}